pub fn is_simple_sql_name(value: &str) -> boolExpand description
Returns a boolean indicating if the supplied string contains a valid simple SQL name. Leading and trailing spaces are ignored. If the value is not quoted, the first character must be alphabetic and the remaining characters must be alphanumeric or contain the characters ‘_’, ‘$’ or ‘#’. A quoted name may not contain embedded quotes and no characters other than whitespace are allowed outside the quotes.